## Summary

<!-- What changed and why -->

## Changes

-

## Testing Performed

- [ ] `ruff check src/ tests/` passes
- [ ] `ruff format --check src/ tests/` passes
- [ ] `mypy src/agentsec/ --ignore-missing-imports` passes
- [ ] `pytest tests/ -v --tb=short` passes
- [ ] Tested manually (describe below)

## Risk & Rollback

- Risks:
- Rollback plan:
